Installation
==================
To get started using asent simply install it using pip by running the following line in your terminal:

.. code-block:: bash

   pip install asent


There is no discrepancy between the latest version installed using pip or the version on GitHub.


Development Installation
^^^^^^^^^^^^^^^^^^^^^^^^^

To set up the development environment for this package, clone the repository and install the
package using the following commands:

.. code-block::

   git clone https://github.com/KennethEnevoldsen/spacy-wrap

   pip install -e ".[style,tests,docs]"